summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/quant_relevance.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/quant_relevance.cpp')
-rw-r--r--src/theory/quantifiers/quant_relevance.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/theory/quantifiers/quant_relevance.cpp b/src/theory/quantifiers/quant_relevance.cpp
index 2a20800c2..2ce79d285 100644
--- a/src/theory/quantifiers/quant_relevance.cpp
+++ b/src/theory/quantifiers/quant_relevance.cpp
@@ -15,10 +15,10 @@
#include "theory/quantifiers/quant_relevance.h"
using namespace std;
-using namespace CVC4::kind;
-using namespace CVC4::context;
+using namespace CVC5::kind;
+using namespace CVC5::context;
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -60,6 +60,6 @@ size_t QuantRelevance::getNumQuantifiersForSymbol(Node s) const
return it->second.size();
}
-} /* CVC4::theory::quantifiers namespace */
-} /* CVC4::theory namespace */
-} /* CVC4 namespace */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback